@@ -226,7 +226,7 @@ pub const ARRAY_FORMAT_VERSION: u8 = 1u8;
 /// Implementation of `ArrayView::from(&S)` where `S` is a slice or slicable.
 ///
 /// Create a one-dimensional read-only array view of the data in `slice`.
-impl<'a, A, Slice: ?Sized> From<&'a Slice> for ArrayBase<ViewRepr<&'a A>, Ix1>
+impl<'a, A, Slice: ?Sized> From<&'a Slice> for ArrayView<'a, A, Ix1>
     where Slice: AsRef<[A]>
 {
     fn from(slice: &'a Slice) -> Self {
@@ -240,7 +240,7 @@ impl<'a, A, Slice: ?Sized> From<&'a Slice> for ArrayBase<ViewRepr<&'a A>, Ix1>
 /// Implementation of `ArrayView::from(&A)` where `A` is an array.
 ///
 /// Create a read-only array view of the array.
-impl<'a, A, S, D> From<&'a ArrayBase<S, D>> for ArrayBase<ViewRepr<&'a A>, D>
+impl<'a, A, S, D> From<&'a ArrayBase<S, D>> for ArrayView<'a, A, D>
     where S: Data<Elem=A>,
           D: Dimension,
 {
@@ -252,7 +252,7 @@ impl<'a, A, S, D> From<&'a ArrayBase<S, D>> for ArrayBase<ViewRepr<&'a A>, D>
 /// Implementation of `ArrayViewMut::from(&mut S)` where `S` is a slice or slicable.
 ///
 /// Create a one-dimensional read-write array view of the data in `slice`.
-impl<'a, A, Slice: ?Sized> From<&'a mut Slice> for ArrayBase<ViewRepr<&'a mut A>, Ix1>
+impl<'a, A, Slice: ?Sized> From<&'a mut Slice> for ArrayViewMut<'a, A, Ix1>
     where Slice: AsMut<[A]>
 {
     fn from(slice: &'a mut Slice) -> Self {
@@ -266,7 +266,7 @@ impl<'a, A, Slice: ?Sized> From<&'a mut Slice> for ArrayBase<ViewRepr<&'a mut A>
 /// Implementation of `ArrayViewMut::from(&mut A)` where `A` is an array.
 ///
 /// Create a read-write array view of the array.
-impl<'a, A, S, D> From<&'a mut ArrayBase<S, D>> for ArrayBase<ViewRepr<&'a mut A>, D>
+impl<'a, A, S, D> From<&'a mut ArrayBase<S, D>> for ArrayViewMut<'a, A, D>
     where S: DataMut<Elem=A>,
           D: Dimension,
 {
