@@ -22,9 +22,6 @@ impl Axis {
     /// Return the index of the axis.
     #[inline(always)]
     pub fn index(&self) -> usize { self.0 }
-    #[deprecated(note = "Renamed to .index()")]
-    #[inline(always)]
-    pub fn axis(&self) -> usize { self.0 }
 }
 
 copy_and_clone!{Axis}
